@@ -42,6 +42,8 @@ class ConditionStep(Step):
         self,
         name: str,
         depends_on: Union[List[str], List[Step]] = None,
+        display_name: str = None,
+        description: str = None,
         conditions: List[Condition] = None,
         if_steps: List[Union[Step, StepCollection]] = None,
         else_steps: List[Union[Step, StepCollection]] = None,
@@ -53,6 +55,9 @@ class ConditionStep(Step):
         execution.
 
         Args:
+            name (str): The name of the condition step.
+            display_name (str): The display name of the condition step.
+            description (str): The description of the condition step.
             conditions (List[Condition]): A list of `sagemaker.workflow.conditions.Condition`
                 instances.
             if_steps (List[Union[Step, StepCollection]]): A list of `sagemaker.workflow.steps.Step`
@@ -62,7 +67,9 @@ class ConditionStep(Step):
                 or `sagemaker.workflow.step_collections.StepCollection` instances that are
                 marked as ready for execution if the list of conditions evaluates to False.
         """
-        super(ConditionStep, self).__init__(name, StepTypeEnum.CONDITION, depends_on)
+        super(ConditionStep, self).__init__(
+            name, display_name, description, StepTypeEnum.CONDITION, depends_on
+        )
         self.conditions = conditions or []
         self.if_steps = if_steps or []
         self.else_steps = else_steps or []
