@@ -25,6 +25,7 @@ from botocore.exceptions import ClientError
 from sagemaker._studio import _append_project_tags
 from sagemaker.session import Session
 from sagemaker.workflow.callback_step import CallbackOutput, CallbackStep
+from sagemaker.workflow.lambda_step import LambdaOutput, LambdaStep
 from sagemaker.workflow.entities import (
     Entity,
     Expression,
@@ -255,11 +256,14 @@ sagemaker.html#SageMaker.Client.describe_pipeline>`_
         """Converts a request structure to string representation for workflow service calls."""
         request_dict = self.to_request()
         request_dict["PipelineExperimentConfig"] = interpolate(
-            request_dict["PipelineExperimentConfig"], {}
+            request_dict["PipelineExperimentConfig"], {}, {}
         )
         callback_output_to_step_map = _map_callback_outputs(self.steps)
+        lambda_output_to_step_name = _map_lambda_outputs(self.steps)
         request_dict["Steps"] = interpolate(
-            request_dict["Steps"], callback_output_to_step_map=callback_output_to_step_map
+            request_dict["Steps"],
+            callback_output_to_step_map=callback_output_to_step_map,
+            lambda_output_to_step_map=lambda_output_to_step_name,
         )
 
         return json.dumps(request_dict)
@@ -282,7 +286,9 @@ def format_start_parameters(parameters: Dict[str, Any]) -> List[Dict[str, Any]]:
 
 
 def interpolate(
-    request_obj: RequestType, callback_output_to_step_map: Dict[str, str]
+    request_obj: RequestType,
+    callback_output_to_step_map: Dict[str, str],
+    lambda_output_to_step_map: Dict[str, str],
 ) -> RequestType:
     """Replaces Parameter values in a list of nested Dict[str, Any] with their workflow expression.
 
@@ -294,10 +300,18 @@ def interpolate(
         RequestType: The request dict with Parameter values replaced by their expression.
     """
     request_obj_copy = deepcopy(request_obj)
-    return _interpolate(request_obj_copy, callback_output_to_step_map=callback_output_to_step_map)
+    return _interpolate(
+        request_obj_copy,
+        callback_output_to_step_map=callback_output_to_step_map,
+        lambda_output_to_step_map=lambda_output_to_step_map,
+    )
 
 
-def _interpolate(obj: Union[RequestType, Any], callback_output_to_step_map: Dict[str, str]):
+def _interpolate(
+    obj: Union[RequestType, Any],
+    callback_output_to_step_map: Dict[str, str],
+    lambda_output_to_step_map: Dict[str, str],
+):
     """Walks the nested request dict, replacing Parameter type values with workflow expressions.
 
     Args:
@@ -306,15 +320,22 @@ def _interpolate(obj: Union[RequestType, Any], callback_output_to_step_map: Dict
     """
     if isinstance(obj, (Expression, Parameter, Properties)):
         return obj.expr
+
     if isinstance(obj, CallbackOutput):
         step_name = callback_output_to_step_map[obj.output_name]
         return obj.expr(step_name)
+    if isinstance(obj, LambdaOutput):
+        step_name = lambda_output_to_step_map[obj.output_name]
+        return obj.expr(step_name)
     if isinstance(obj, dict):
         new = obj.__class__()
         for key, value in obj.items():
-            new[key] = interpolate(value, callback_output_to_step_map)
+            new[key] = interpolate(value, callback_output_to_step_map, lambda_output_to_step_map)
     elif isinstance(obj, (list, set, tuple)):
-        new = obj.__class__(interpolate(value, callback_output_to_step_map) for value in obj)
+        new = obj.__class__(
+            interpolate(value, callback_output_to_step_map, lambda_output_to_step_map)
+            for value in obj
+        )
     else:
         return obj
     return new
@@ -337,6 +358,23 @@ def _map_callback_outputs(steps: List[Step]):
     return callback_output_map
 
 
+def _map_lambda_outputs(steps: List[Step]):
+    """Iterate over the provided steps, building a map of lambda output parameters to step names.
+
+    Args:
+        step (List[Step]): The steps list.
+    """
+
+    lambda_output_map = {}
+    for step in steps:
+        if isinstance(step, LambdaStep):
+            if step.outputs:
+                for output in step.outputs:
+                    lambda_output_map[output.output_name] = step.name
+
+    return lambda_output_map
+
+
 def update_args(args: Dict[str, Any], **kwargs):
     """Updates the request arguments dict with a value, if populated.
 
